@@ -3,7 +3,8 @@ import transaction
 
 from pyramid import testing
 
-from ..models.models import DBSession
+from ..models import DBSession
+
 
 class TestMyView(unittest.TestCase):
     def setUp(self):
